'use strict';

var helperPluginUtils = require('@babel/helper-plugin-utils');
var proposalClassProperties = require('@babel/plugin-proposal-class-properties');
var proposalClassStaticBlock = require('@babel/plugin-proposal-class-static-block');
var proposalDoExpressions = require('@babel/plugin-proposal-do-expressions');
var proposalFunctionBind = require('@babel/plugin-proposal-function-bind');
var proposalFunctionSent = require('@babel/plugin-proposal-function-sent');
var proposalJsonStrings = require('@babel/plugin-proposal-json-strings');
var proposalOptionalChaining = require('@babel/plugin-proposal-optional-chaining');
var proposalPartialApplication = require('@babel/plugin-proposal-partial-application');
var proposalPipelineOperator = require('@babel/plugin-proposal-pipeline-operator');
var proposalPrivateMethods = require('@babel/plugin-proposal-private-methods');
var proposalPrivatePropertyInObject = require('@babel/plugin-proposal-private-property-in-object');
var proposalThrowExpression = require('@babel/plugin-proposal-throw-expressions');
var syntaxDecorators = require('@babel/plugin-syntax-decorators');
var syntaxDynamicImport = require('@babel/plugin-syntax-dynamic-import');
var syntaxTypeScript = require('@babel/plugin-syntax-typescript');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var proposalClassProperties__default = /*#__PURE__*/_interopDefaultLegacy(proposalClassProperties);
var proposalClassStaticBlock__default = /*#__PURE__*/_interopDefaultLegacy(proposalClassStaticBlock);
var proposalDoExpressions__default = /*#__PURE__*/_interopDefaultLegacy(proposalDoExpressions);
var proposalFunctionBind__default = /*#__PURE__*/_interopDefaultLegacy(proposalFunctionBind);
var proposalFunctionSent__default = /*#__PURE__*/_interopDefaultLegacy(proposalFunctionSent);
var proposalJsonStrings__default = /*#__PURE__*/_interopDefaultLegacy(proposalJsonStrings);
var proposalOptionalChaining__default = /*#__PURE__*/_interopDefaultLegacy(proposalOptionalChaining);
var proposalPartialApplication__default = /*#__PURE__*/_interopDefaultLegacy(proposalPartialApplication);
var proposalPipelineOperator__default = /*#__PURE__*/_interopDefaultLegacy(proposalPipelineOperator);
var proposalPrivateMethods__default = /*#__PURE__*/_interopDefaultLegacy(proposalPrivateMethods);
var proposalPrivatePropertyInObject__default = /*#__PURE__*/_interopDefaultLegacy(proposalPrivatePropertyInObject);
var proposalThrowExpression__default = /*#__PURE__*/_interopDefaultLegacy(proposalThrowExpression);
var syntaxDecorators__default = /*#__PURE__*/_interopDefaultLegacy(syntaxDecorators);
var syntaxDynamicImport__default = /*#__PURE__*/_interopDefaultLegacy(syntaxDynamicImport);
var syntaxTypeScript__default = /*#__PURE__*/_interopDefaultLegacy(syntaxTypeScript);

var syntaxV8intrinsic = helperPluginUtils.declare(function (api) {
    api.assertVersion(7);
    return {
        name: 'v8intrinsic',
        manipulateOptions: function (_opts, parserOpts) {
            parserOpts.plugins.push('v8intrinsic');
        },
    };
});

var index = helperPluginUtils.declare(function (api, _a) {
    var _b = _a.classLoose, classLoose = _b === void 0 ? true : _b, decoratorsBeforeExport = _a.decoratorsBeforeExport, _c = _a.decoratorsLegacy, decoratorsLegacy = _c === void 0 ? true : _c, isTSX = _a.isTSX, _d = _a.pipelineOperator, pipelineOperator = _d === void 0 ? 'minimal' : _d;
    api.assertVersion(7);
    return {
        plugins: [
            [
                syntaxDecorators__default['default'],
                {
                    decoratorsBeforeExport: decoratorsBeforeExport,
                    legacy: decoratorsLegacy,
                },
            ],
            syntaxDynamicImport__default['default'],
            [
                syntaxTypeScript__default['default'],
                {
                    isTSX: isTSX,
                },
            ],
            syntaxV8intrinsic,
            [
                proposalClassStaticBlock__default['default'],
                {
                    loose: classLoose,
                },
            ],
            [
                proposalClassProperties__default['default'],
                {
                    loose: classLoose,
                },
            ],
            proposalDoExpressions__default['default'],
            proposalFunctionBind__default['default'],
            proposalFunctionSent__default['default'],
            proposalJsonStrings__default['default'],
            proposalOptionalChaining__default['default'],
            proposalPartialApplication__default['default'],
            [
                proposalPipelineOperator__default['default'],
                {
                    proposal: pipelineOperator,
                },
            ],
            [
                proposalPrivateMethods__default['default'],
                {
                    loose: classLoose,
                },
            ],
            [
                proposalPrivatePropertyInObject__default['default'],
                {
                    loose: classLoose,
                },
            ],
            proposalThrowExpression__default['default'],
        ],
        // no need to override if it has been enabled
        overrides: isTSX
            ? undefined
            : [
                {
                    test: /\.[jt]sx$/,
                    plugins: [
                        [
                            syntaxTypeScript__default['default'],
                            {
                                isTSX: true,
                            },
                        ],
                    ],
                },
            ],
    };
});

module.exports = index;
